@@ -6,8 +6,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_ETMVIEWSTATESAVER_H
-#define AKONADI_ETMVIEWSTATESAVER_H
+#pragma once
 
 #include <KConfigViewStateSaver>
 
@@ -18,8 +17,7 @@
 
 namespace Akonadi
 {
-
-class AKONADIWIDGETS_EXPORT ETMViewStateSaver : public KConfigViewStateSaver  //krazy:exclude=dpointer
+class AKONADIWIDGETS_EXPORT ETMViewStateSaver : public KConfigViewStateSaver // krazy:exclude=dpointer
 {
     Q_OBJECT
 public:
@@ -37,9 +35,7 @@ protected:
     /* reimp */
     QModelIndex indexFromConfigString(const QAbstractItemModel *model, const QString &key) const override;
     QString indexToConfigString(const QModelIndex &index) const override;
-
 };
 
 }
 
-#endif
