@@ -6,8 +6,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_TAGSELECTIONDIALOG_H
-#define AKONADI_TAGSELECTIONDIALOG_H
+#pragma once
 
 #include "akonadiwidgets_export.h"
 
@@ -18,7 +17,6 @@
 class QDialogButtonBox;
 namespace Akonadi
 {
-
 class TagModel;
 
 /**
@@ -50,4 +48,3 @@ private:
 
 }
 
-#endif
